.trigger-container[data-v-fb0902ef]{display:flex;align-items:center;gap:.25rem;width:100%}.trigger-container.flex-col[data-v-fb0902ef]{flex-direction:column;justify-content:center}.trigger-container.flex-row[data-v-fb0902ef]{flex-direction:row}.ha-logo-icon[data-v-fb0902ef]{width:16px;height:16px;display:block;margin:auto}.mobile-sidebar-trigger[data-v-00709166]{min-width:0;padding:0;margin-right:4px}.header.v-toolbar[data-v-6e429669]{height:55px;font-family:JetBrains Mono Medium}.header.v-toolbar[data-v-6e429669] .v-toolbar__content{height:55px!important;min-height:55px!important;padding-top:0;padding-bottom:0;align-items:center}.header.v-toolbar[data-v-6e429669] .v-toolbar-title{margin-inline-start:10px!important}.header.v-toolbar[data-v-6e429669] .v-toolbar__prepend{margin-inline-start:12px!important;margin-inline-end:0px!important}.header.v-toolbar>.v-toolbar__content>.v-toolbar__append[data-v-6e429669]{margin-inline-end:5px}.header.v-toolbar-default>.v-toolbar__content>.v-toolbar__append[data-v-6e429669]{margin-inline-end:10px}.toolbar-prepend[data-v-6e429669]{display:flex;align-items:center;gap:.5rem}
